@@ -7,6 +7,7 @@ use Mojo::Base qw/-base/;
 use Mojo::UserAgent;
 use Mojo::ByteStream qw/b/;
 use Mojo::Parameters;
+use Clustericious;
 use Clustericious::Config;
 use Clustericious::Client::Object;
 use Clustericious::Client::Meta;
@@ -17,7 +18,7 @@ use File::Temp;
 use JSON::MaybeXS qw( encode_json decode_json );
 
 # ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.10_02'; # TRIAL VERSION
+our $VERSION = '1.10_03'; # TRIAL VERSION
 
 
 has server_url => '';
@@ -520,6 +521,7 @@ sub _base_config {
     $config_name =~ s/::/-/;
     
     $self->{_base_config} = Clustericious::Config->new($config_name);
+    $self->{_base_config}->{url} //= Clustericious->_default_url($config_name);
     return $self->{_base_config};
 }
 
@@ -608,7 +610,7 @@ Clustericious::Client - Construct command line and perl clients for RESTful serv
 
 =head1 VERSION
 
-version 1.10_02
+version 1.10_03
 
 =head1 SYNOPSIS
 
