@@ -17,7 +17,7 @@ use YAML::XS ();
 use File::Temp qw( tempdir );
 
 # ABSTRACT: Test Clustericious commands
-our $VERSION = '1.10_02'; # TRIAL VERSION
+our $VERSION = '1.10_03'; # TRIAL VERSION
 
 
 our @EXPORT      = qw( extract_data mirror requires run_ok generate_port note_file clean_file create_symlink );
@@ -179,7 +179,7 @@ sub run_ok
   
   my $tb = __PACKAGE__->builder;
   
-  $tb->ok($ok, "@cmd");
+  $tb->ok($ok, "run: @cmd");
   $tb->diag("  @cmd failed") unless $ok;
   $tb->diag("    - execute failed: $error") if $exit == -1;
   $tb->diag("    - died from signal: " . ($exit & 128)) if $exit & 128;
@@ -343,7 +343,7 @@ Test::Clustericious::Command - Test Clustericious commands
 
 =head1 VERSION
 
-version 1.10_02
+version 1.10_03
 
 =head1 SYNOPSIS
 
